# face-to-face

Library for easy-to-use human face related trained models.

## Models

### Face Detection

* FAN
* SCRFD

### Face Landmark Detection

* ResNet50d, insightface provided (trained with Microsoft FaceSynthetics)

### Face Segmentation

* BiSeNet

### Human matting

* SGHM (Semantic Guided Human Matting)
* MODNet

### 3DMM (3D Morphable Model)

* BFM
* FLAME

### Face to 3DMM

* DECA
* EMOCA
* MICA
* Deep3DFaceRecon

### Wav2MM (Wav to 3D Morphable Model)

* FaceFormer

## Pretrained Weights

* Automatically download from [release](https://github.com/kynk94/face-to-face/releases/tag/weights-v0.1)
